=======
Support
=======

AS3 Ninja is an open source project started by a single individual and released under the `ISC license`_.

.. _`ISC license`: https://github.com/simonkowallik/as3ninja/blob/master/LICENSE

By using AS3 Ninja you confirm to understand, agree and adhere to the license.


.. Warning:: **There is no commercial/technical support nor any other form of support for AS3 Ninja. It comes without SLAs or any form of warranty.**


You are welcome to :doc:`contribute <contributing>`, for example by opening a `GitHub issue`_ to report a problem.

.. _`GitHub issue`: https://github.com/simonkowallik/as3ninja
